// Copyright 2016 Workiva Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

/// Various prop related mixins to be used with [UiComponent] descendants.
library over_react.prop_mixins;

// Must import these consts because they are used in the transformed code.
// ignore: unused_import
import 'package:over_react/over_react.dart' show PropDescriptor, ConsumedProps;
import 'package:over_react/src/component/callback_typedefs.dart';
import 'package:over_react/src/component_declaration/annotations.dart';

/// Typed getters/setters for reserved React props.
/// To be used as a mixin for React components and builders.
@PropsMixin(keyNamespace: '')
abstract class ReactPropsMixin {    /* GENERATED CONSTANTS */ static const ConsumedProps $consumedProps = const ConsumedProps($props, $propKeys); static const PropDescriptor _$prop__children = const PropDescriptor(_$key__children), _$prop__ref = const PropDescriptor(_$key__ref); static const List<PropDescriptor> $props = const [_$prop__children, _$prop__ref]; static const String _$key__children = 'children', _$key__ref = 'ref'; static const List<String> $propKeys = const [_$key__children, _$key__ref]; 
  Map get props;

  /// The children that were passed in to this component when it was built.
  List get children => props[_$key__children];  set children(List value) => props[_$key__children] = value;

  /// A String that differentiates a component from its siblings.
  ///
  /// When setting [key] you can use any [Object], its `toString()` method will be called when applying the value.
  ///
  /// Keys are necessary when children are dynamic, such as those passed in as a [List],
  /// but are generally not required when using variadic children.
  ///
  /// For more info, see:
  ///
  /// * <https://facebook.github.io/react/docs/multiple-components.html#children>
  /// * <https://facebook.github.io/react/docs/reconciliation.html>
  String get key        => props['key'];
  set key(Object value) => props['key'] = value == null ? null : value.toString();

  /// Either a String used to retrieve the element at a later time via [react.Component.ref],
  /// or a Function that gets called with the element when it is mounted.
  ///
  /// See: <https://facebook.github.io/react/docs/more-about-refs.html>.
  dynamic get ref => props[_$key__ref];  set ref(dynamic value) => props[_$key__ref] = value;
}

/// Typed getters/setters for reserved DOM-related props.
/// To be used as a mixin for React components and builders.
@PropsMixin(keyNamespace: '')
abstract class DomPropsMixin {    /* GENERATED CONSTANTS */ static const ConsumedProps $consumedProps = const ConsumedProps($props, $propKeys); static const PropDescriptor _$prop__cols = const PropDescriptor(_$key__cols), _$prop__rows = const PropDescriptor(_$key__rows), _$prop__size = const PropDescriptor(_$key__size), _$prop__span = const PropDescriptor(_$key__span), _$prop__start = const PropDescriptor(_$key__start), _$prop__allowFullScreen = const PropDescriptor(_$key__allowFullScreen), _$prop__async = const PropDescriptor(_$key__async), _$prop__autoPlay = const PropDescriptor(_$key__autoPlay), _$prop__checked = const PropDescriptor(_$key__checked), _$prop__controls = const PropDescriptor(_$key__controls), _$prop__defer = const PropDescriptor(_$key__defer), _$prop__disabled = const PropDescriptor(_$key__disabled), _$prop__formNoValidate = const PropDescriptor(_$key__formNoValidate), _$prop__hidden = const PropDescriptor(_$key__hidden), _$prop__loop = const PropDescriptor(_$key__loop), _$prop__multiple = const PropDescriptor(_$key__multiple), _$prop__muted = const PropDescriptor(_$key__muted), _$prop__noValidate = const PropDescriptor(_$key__noValidate), _$prop__readOnly = const PropDescriptor(_$key__readOnly), _$prop__required = const PropDescriptor(_$key__required), _$prop__seamless = const PropDescriptor(_$key__seamless), _$prop__selected = const PropDescriptor(_$key__selected), _$prop__style = const PropDescriptor(_$key__style), _$prop__className = const PropDescriptor(_$key__className), _$prop__title = const PropDescriptor(_$key__title), _$prop__id = const PropDescriptor(_$key__id), _$prop__accept = const PropDescriptor(_$key__accept), _$prop__acceptCharset = const PropDescriptor(_$key__acceptCharset), _$prop__accessKey = const PropDescriptor(_$key__accessKey), _$prop__action = const PropDescriptor(_$key__action), _$prop__allowTransparency = const PropDescriptor(_$key__allowTransparency), _$prop__alt = const PropDescriptor(_$key__alt), _$prop__autoComplete = const PropDescriptor(_$key__autoComplete), _$prop__cellPadding = const PropDescriptor(_$key__cellPadding), _$prop__cellSpacing = const PropDescriptor(_$key__cellSpacing), _$prop__charSet = const PropDescriptor(_$key__charSet), _$prop__classID = const PropDescriptor(_$key__classID), _$prop__colSpan = const PropDescriptor(_$key__colSpan), _$prop__content = const PropDescriptor(_$key__content), _$prop__contentEditable = const PropDescriptor(_$key__contentEditable), _$prop__contextMenu = const PropDescriptor(_$key__contextMenu), _$prop__coords = const PropDescriptor(_$key__coords), _$prop__crossOrigin = const PropDescriptor(_$key__crossOrigin), _$prop__data = const PropDescriptor(_$key__data), _$prop__dateTime = const PropDescriptor(_$key__dateTime), _$prop__dir = const PropDescriptor(_$key__dir), _$prop__download = const PropDescriptor(_$key__download), _$prop__draggable = const PropDescriptor(_$key__draggable), _$prop__encType = const PropDescriptor(_$key__encType), _$prop__form = const PropDescriptor(_$key__form), _$prop__frameBorder = const PropDescriptor(_$key__frameBorder), _$prop__height = const PropDescriptor(_$key__height), _$prop__href = const PropDescriptor(_$key__href), _$prop__hrefLang = const PropDescriptor(_$key__hrefLang), _$prop__htmlFor = const PropDescriptor(_$key__htmlFor), _$prop__httpEquiv = const PropDescriptor(_$key__httpEquiv), _$prop__icon = const PropDescriptor(_$key__icon), _$prop__label = const PropDescriptor(_$key__label), _$prop__lang = const PropDescriptor(_$key__lang), _$prop__list = const PropDescriptor(_$key__list), _$prop__manifest = const PropDescriptor(_$key__manifest), _$prop__max = const PropDescriptor(_$key__max), _$prop__maxLength = const PropDescriptor(_$key__maxLength), _$prop__media = const PropDescriptor(_$key__media), _$prop__mediaGroup = const PropDescriptor(_$key__mediaGroup), _$prop__method = const PropDescriptor(_$key__method), _$prop__min = const PropDescriptor(_$key__min), _$prop__name = const PropDescriptor(_$key__name), _$prop__open = const PropDescriptor(_$key__open), _$prop__pattern = const PropDescriptor(_$key__pattern), _$prop__placeholder = const PropDescriptor(_$key__placeholder), _$prop__poster = const PropDescriptor(_$key__poster), _$prop__preload = const PropDescriptor(_$key__preload), _$prop__radioGroup = const PropDescriptor(_$key__radioGroup), _$prop__rel = const PropDescriptor(_$key__rel), _$prop__role = const PropDescriptor(_$key__role), _$prop__rowSpan = const PropDescriptor(_$key__rowSpan), _$prop__sandbox = const PropDescriptor(_$key__sandbox), _$prop__scope = const PropDescriptor(_$key__scope), _$prop__scrolling = const PropDescriptor(_$key__scrolling), _$prop__shape = const PropDescriptor(_$key__shape), _$prop__sizes = const PropDescriptor(_$key__sizes), _$prop__spellCheck = const PropDescriptor(_$key__spellCheck), _$prop__src = const PropDescriptor(_$key__src), _$prop__srcDoc = const PropDescriptor(_$key__srcDoc), _$prop__srcSet = const PropDescriptor(_$key__srcSet), _$prop__step = const PropDescriptor(_$key__step), _$prop__tabIndex = const PropDescriptor(_$key__tabIndex), _$prop__target = const PropDescriptor(_$key__target), _$prop__type = const PropDescriptor(_$key__type), _$prop__useMap = const PropDescriptor(_$key__useMap), _$prop__value = const PropDescriptor(_$key__value), _$prop__width = const PropDescriptor(_$key__width), _$prop__wmode = const PropDescriptor(_$key__wmode), _$prop__onCopy = const PropDescriptor(_$key__onCopy), _$prop__onCut = const PropDescriptor(_$key__onCut), _$prop__onPaste = const PropDescriptor(_$key__onPaste), _$prop__onKeyDown = const PropDescriptor(_$key__onKeyDown), _$prop__onKeyPress = const PropDescriptor(_$key__onKeyPress), _$prop__onKeyUp = const PropDescriptor(_$key__onKeyUp), _$prop__onFocus = const PropDescriptor(_$key__onFocus), _$prop__onBlur = const PropDescriptor(_$key__onBlur), _$prop__onChange = const PropDescriptor(_$key__onChange), _$prop__onInput = const PropDescriptor(_$key__onInput), _$prop__onSubmit = const PropDescriptor(_$key__onSubmit), _$prop__onReset = const PropDescriptor(_$key__onReset), _$prop__onClick = const PropDescriptor(_$key__onClick), _$prop__onContextMenu = const PropDescriptor(_$key__onContextMenu), _$prop__onDoubleClick = const PropDescriptor(_$key__onDoubleClick), _$prop__onDrag = const PropDescriptor(_$key__onDrag), _$prop__onDragEnd = const PropDescriptor(_$key__onDragEnd), _$prop__onDragEnter = const PropDescriptor(_$key__onDragEnter), _$prop__onDragExit = const PropDescriptor(_$key__onDragExit), _$prop__onDragLeave = const PropDescriptor(_$key__onDragLeave), _$prop__onDragOver = const PropDescriptor(_$key__onDragOver), _$prop__onDragStart = const PropDescriptor(_$key__onDragStart), _$prop__onDrop = const PropDescriptor(_$key__onDrop), _$prop__onMouseDown = const PropDescriptor(_$key__onMouseDown), _$prop__onMouseEnter = const PropDescriptor(_$key__onMouseEnter), _$prop__onMouseLeave = const PropDescriptor(_$key__onMouseLeave), _$prop__onMouseMove = const PropDescriptor(_$key__onMouseMove), _$prop__onMouseOut = const PropDescriptor(_$key__onMouseOut), _$prop__onMouseOver = const PropDescriptor(_$key__onMouseOver), _$prop__onMouseUp = const PropDescriptor(_$key__onMouseUp), _$prop__onTouchCancel = const PropDescriptor(_$key__onTouchCancel), _$prop__onTouchEnd = const PropDescriptor(_$key__onTouchEnd), _$prop__onTouchMove = const PropDescriptor(_$key__onTouchMove), _$prop__onTouchStart = const PropDescriptor(_$key__onTouchStart), _$prop__onScroll = const PropDescriptor(_$key__onScroll), _$prop__onWheel = const PropDescriptor(_$key__onWheel), _$prop__defaultChecked = const PropDescriptor(_$key__defaultChecked), _$prop__defaultValue = const PropDescriptor(_$key__defaultValue), _$prop__autoFocus = const PropDescriptor(_$key__autoFocus); static const List<PropDescriptor> $props = const [_$prop__cols, _$prop__rows, _$prop__size, _$prop__span, _$prop__start, _$prop__allowFullScreen, _$prop__async, _$prop__autoPlay, _$prop__checked, _$prop__controls, _$prop__defer, _$prop__disabled, _$prop__formNoValidate, _$prop__hidden, _$prop__loop, _$prop__multiple, _$prop__muted, _$prop__noValidate, _$prop__readOnly, _$prop__required, _$prop__seamless, _$prop__selected, _$prop__style, _$prop__className, _$prop__title, _$prop__id, _$prop__accept, _$prop__acceptCharset, _$prop__accessKey, _$prop__action, _$prop__allowTransparency, _$prop__alt, _$prop__autoComplete, _$prop__cellPadding, _$prop__cellSpacing, _$prop__charSet, _$prop__classID, _$prop__colSpan, _$prop__content, _$prop__contentEditable, _$prop__contextMenu, _$prop__coords, _$prop__crossOrigin, _$prop__data, _$prop__dateTime, _$prop__dir, _$prop__download, _$prop__draggable, _$prop__encType, _$prop__form, _$prop__frameBorder, _$prop__height, _$prop__href, _$prop__hrefLang, _$prop__htmlFor, _$prop__httpEquiv, _$prop__icon, _$prop__label, _$prop__lang, _$prop__list, _$prop__manifest, _$prop__max, _$prop__maxLength, _$prop__media, _$prop__mediaGroup, _$prop__method, _$prop__min, _$prop__name, _$prop__open, _$prop__pattern, _$prop__placeholder, _$prop__poster, _$prop__preload, _$prop__radioGroup, _$prop__rel, _$prop__role, _$prop__rowSpan, _$prop__sandbox, _$prop__scope, _$prop__scrolling, _$prop__shape, _$prop__sizes, _$prop__spellCheck, _$prop__src, _$prop__srcDoc, _$prop__srcSet, _$prop__step, _$prop__tabIndex, _$prop__target, _$prop__type, _$prop__useMap, _$prop__value, _$prop__width, _$prop__wmode, _$prop__onCopy, _$prop__onCut, _$prop__onPaste, _$prop__onKeyDown, _$prop__onKeyPress, _$prop__onKeyUp, _$prop__onFocus, _$prop__onBlur, _$prop__onChange, _$prop__onInput, _$prop__onSubmit, _$prop__onReset, _$prop__onClick, _$prop__onContextMenu, _$prop__onDoubleClick, _$prop__onDrag, _$prop__onDragEnd, _$prop__onDragEnter, _$prop__onDragExit, _$prop__onDragLeave, _$prop__onDragOver, _$prop__onDragStart, _$prop__onDrop, _$prop__onMouseDown, _$prop__onMouseEnter, _$prop__onMouseLeave, _$prop__onMouseMove, _$prop__onMouseOut, _$prop__onMouseOver, _$prop__onMouseUp, _$prop__onTouchCancel, _$prop__onTouchEnd, _$prop__onTouchMove, _$prop__onTouchStart, _$prop__onScroll, _$prop__onWheel, _$prop__defaultChecked, _$prop__defaultValue, _$prop__autoFocus]; static const String _$key__cols = 'cols', _$key__rows = 'rows', _$key__size = 'size', _$key__span = 'span', _$key__start = 'start', _$key__allowFullScreen = 'allowFullScreen', _$key__async = 'async', _$key__autoPlay = 'autoPlay', _$key__checked = 'checked', _$key__controls = 'controls', _$key__defer = 'defer', _$key__disabled = 'disabled', _$key__formNoValidate = 'formNoValidate', _$key__hidden = 'hidden', _$key__loop = 'loop', _$key__multiple = 'multiple', _$key__muted = 'muted', _$key__noValidate = 'noValidate', _$key__readOnly = 'readOnly', _$key__required = 'required', _$key__seamless = 'seamless', _$key__selected = 'selected', _$key__style = 'style', _$key__className = 'className', _$key__title = 'title', _$key__id = 'id', _$key__accept = 'accept', _$key__acceptCharset = 'acceptCharset', _$key__accessKey = 'accessKey', _$key__action = 'action', _$key__allowTransparency = 'allowTransparency', _$key__alt = 'alt', _$key__autoComplete = 'autoComplete', _$key__cellPadding = 'cellPadding', _$key__cellSpacing = 'cellSpacing', _$key__charSet = 'charSet', _$key__classID = 'classID', _$key__colSpan = 'colSpan', _$key__content = 'content', _$key__contentEditable = 'contentEditable', _$key__contextMenu = 'contextMenu', _$key__coords = 'coords', _$key__crossOrigin = 'crossOrigin', _$key__data = 'data', _$key__dateTime = 'dateTime', _$key__dir = 'dir', _$key__download = 'download', _$key__draggable = 'draggable', _$key__encType = 'encType', _$key__form = 'form', _$key__frameBorder = 'frameBorder', _$key__height = 'height', _$key__href = 'href', _$key__hrefLang = 'hrefLang', _$key__htmlFor = 'htmlFor', _$key__httpEquiv = 'httpEquiv', _$key__icon = 'icon', _$key__label = 'label', _$key__lang = 'lang', _$key__list = 'list', _$key__manifest = 'manifest', _$key__max = 'max', _$key__maxLength = 'maxLength', _$key__media = 'media', _$key__mediaGroup = 'mediaGroup', _$key__method = 'method', _$key__min = 'min', _$key__name = 'name', _$key__open = 'open', _$key__pattern = 'pattern', _$key__placeholder = 'placeholder', _$key__poster = 'poster', _$key__preload = 'preload', _$key__radioGroup = 'radioGroup', _$key__rel = 'rel', _$key__role = 'role', _$key__rowSpan = 'rowSpan', _$key__sandbox = 'sandbox', _$key__scope = 'scope', _$key__scrolling = 'scrolling', _$key__shape = 'shape', _$key__sizes = 'sizes', _$key__spellCheck = 'spellCheck', _$key__src = 'src', _$key__srcDoc = 'srcDoc', _$key__srcSet = 'srcSet', _$key__step = 'step', _$key__tabIndex = 'tabIndex', _$key__target = 'target', _$key__type = 'type', _$key__useMap = 'useMap', _$key__value = 'value', _$key__width = 'width', _$key__wmode = 'wmode', _$key__onCopy = 'onCopy', _$key__onCut = 'onCut', _$key__onPaste = 'onPaste', _$key__onKeyDown = 'onKeyDown', _$key__onKeyPress = 'onKeyPress', _$key__onKeyUp = 'onKeyUp', _$key__onFocus = 'onFocus', _$key__onBlur = 'onBlur', _$key__onChange = 'onChange', _$key__onInput = 'onInput', _$key__onSubmit = 'onSubmit', _$key__onReset = 'onReset', _$key__onClick = 'onClick', _$key__onContextMenu = 'onContextMenu', _$key__onDoubleClick = 'onDoubleClick', _$key__onDrag = 'onDrag', _$key__onDragEnd = 'onDragEnd', _$key__onDragEnter = 'onDragEnter', _$key__onDragExit = 'onDragExit', _$key__onDragLeave = 'onDragLeave', _$key__onDragOver = 'onDragOver', _$key__onDragStart = 'onDragStart', _$key__onDrop = 'onDrop', _$key__onMouseDown = 'onMouseDown', _$key__onMouseEnter = 'onMouseEnter', _$key__onMouseLeave = 'onMouseLeave', _$key__onMouseMove = 'onMouseMove', _$key__onMouseOut = 'onMouseOut', _$key__onMouseOver = 'onMouseOver', _$key__onMouseUp = 'onMouseUp', _$key__onTouchCancel = 'onTouchCancel', _$key__onTouchEnd = 'onTouchEnd', _$key__onTouchMove = 'onTouchMove', _$key__onTouchStart = 'onTouchStart', _$key__onScroll = 'onScroll', _$key__onWheel = 'onWheel', _$key__defaultChecked = 'defaultChecked', _$key__defaultValue = 'defaultValue', _$key__autoFocus = 'autoFocus'; static const List<String> $propKeys = const [_$key__cols, _$key__rows, _$key__size, _$key__span, _$key__start, _$key__allowFullScreen, _$key__async, _$key__autoPlay, _$key__checked, _$key__controls, _$key__defer, _$key__disabled, _$key__formNoValidate, _$key__hidden, _$key__loop, _$key__multiple, _$key__muted, _$key__noValidate, _$key__readOnly, _$key__required, _$key__seamless, _$key__selected, _$key__style, _$key__className, _$key__title, _$key__id, _$key__accept, _$key__acceptCharset, _$key__accessKey, _$key__action, _$key__allowTransparency, _$key__alt, _$key__autoComplete, _$key__cellPadding, _$key__cellSpacing, _$key__charSet, _$key__classID, _$key__colSpan, _$key__content, _$key__contentEditable, _$key__contextMenu, _$key__coords, _$key__crossOrigin, _$key__data, _$key__dateTime, _$key__dir, _$key__download, _$key__draggable, _$key__encType, _$key__form, _$key__frameBorder, _$key__height, _$key__href, _$key__hrefLang, _$key__htmlFor, _$key__httpEquiv, _$key__icon, _$key__label, _$key__lang, _$key__list, _$key__manifest, _$key__max, _$key__maxLength, _$key__media, _$key__mediaGroup, _$key__method, _$key__min, _$key__name, _$key__open, _$key__pattern, _$key__placeholder, _$key__poster, _$key__preload, _$key__radioGroup, _$key__rel, _$key__role, _$key__rowSpan, _$key__sandbox, _$key__scope, _$key__scrolling, _$key__shape, _$key__sizes, _$key__spellCheck, _$key__src, _$key__srcDoc, _$key__srcSet, _$key__step, _$key__tabIndex, _$key__target, _$key__type, _$key__useMap, _$key__value, _$key__width, _$key__wmode, _$key__onCopy, _$key__onCut, _$key__onPaste, _$key__onKeyDown, _$key__onKeyPress, _$key__onKeyUp, _$key__onFocus, _$key__onBlur, _$key__onChange, _$key__onInput, _$key__onSubmit, _$key__onReset, _$key__onClick, _$key__onContextMenu, _$key__onDoubleClick, _$key__onDrag, _$key__onDragEnd, _$key__onDragEnter, _$key__onDragExit, _$key__onDragLeave, _$key__onDragOver, _$key__onDragStart, _$key__onDrop, _$key__onMouseDown, _$key__onMouseEnter, _$key__onMouseLeave, _$key__onMouseMove, _$key__onMouseOut, _$key__onMouseOver, _$key__onMouseUp, _$key__onTouchCancel, _$key__onTouchEnd, _$key__onTouchMove, _$key__onTouchStart, _$key__onScroll, _$key__onWheel, _$key__defaultChecked, _$key__defaultValue, _$key__autoFocus]; 
  Map get props;

  int get cols => props[_$key__cols];  set cols(int value) => props[_$key__cols] = value;int get rows => props[_$key__rows];  set rows(int value) => props[_$key__rows] = value;int get size => props[_$key__size];  set size(int value) => props[_$key__size] = value;int get span => props[_$key__span];  set span(int value) => props[_$key__span] = value;int get start => props[_$key__start];  set start(int value) => props[_$key__start] = value;

  bool get allowFullScreen => props[_$key__allowFullScreen];  set allowFullScreen(bool value) => props[_$key__allowFullScreen] = value;bool get async => props[_$key__async];  set async(bool value) => props[_$key__async] = value;bool get autoPlay => props[_$key__autoPlay];  set autoPlay(bool value) => props[_$key__autoPlay] = value;bool get checked => props[_$key__checked];  set checked(bool value) => props[_$key__checked] = value;bool get controls => props[_$key__controls];  set controls(bool value) => props[_$key__controls] = value;bool get defer => props[_$key__defer];  set defer(bool value) => props[_$key__defer] = value;bool get disabled => props[_$key__disabled];  set disabled(bool value) => props[_$key__disabled] = value;bool get formNoValidate => props[_$key__formNoValidate];  set formNoValidate(bool value) => props[_$key__formNoValidate] = value;bool get hidden => props[_$key__hidden];  set hidden(bool value) => props[_$key__hidden] = value;bool get loop => props[_$key__loop];  set loop(bool value) => props[_$key__loop] = value;bool get multiple => props[_$key__multiple];  set multiple(bool value) => props[_$key__multiple] = value;
bool get muted => props[_$key__muted];  set muted(bool value) => props[_$key__muted] = value;bool get noValidate => props[_$key__noValidate];  set noValidate(bool value) => props[_$key__noValidate] = value;bool get readOnly => props[_$key__readOnly];  set readOnly(bool value) => props[_$key__readOnly] = value;bool get required => props[_$key__required];  set required(bool value) => props[_$key__required] = value;bool get seamless => props[_$key__seamless];  set seamless(bool value) => props[_$key__seamless] = value;bool get selected => props[_$key__selected];  set selected(bool value) => props[_$key__selected] = value;

  Map<String, dynamic> get style => props[_$key__style];  set style(Map<String, dynamic> value) => props[_$key__style] = value;

  String get className => props[_$key__className];  set className(String value) => props[_$key__className] = value;String get title => props[_$key__title];  set title(String value) => props[_$key__title] = value;String get id => props[_$key__id];  set id(String value) => props[_$key__id] = value;

  dynamic get accept => props[_$key__accept];  set accept(dynamic value) => props[_$key__accept] = value;dynamic get acceptCharset => props[_$key__acceptCharset];  set acceptCharset(dynamic value) => props[_$key__acceptCharset] = value;dynamic get accessKey => props[_$key__accessKey];  set accessKey(dynamic value) => props[_$key__accessKey] = value;dynamic get action => props[_$key__action];  set action(dynamic value) => props[_$key__action] = value;dynamic get allowTransparency => props[_$key__allowTransparency];  set allowTransparency(dynamic value) => props[_$key__allowTransparency] = value;dynamic get alt => props[_$key__alt];  set alt(dynamic value) => props[_$key__alt] = value;dynamic get autoComplete => props[_$key__autoComplete];  set autoComplete(dynamic value) => props[_$key__autoComplete] = value;dynamic get cellPadding => props[_$key__cellPadding];  set cellPadding(dynamic value) => props[_$key__cellPadding] = value;dynamic get cellSpacing => props[_$key__cellSpacing];  set cellSpacing(dynamic value) => props[_$key__cellSpacing] = value;
dynamic get charSet => props[_$key__charSet];  set charSet(dynamic value) => props[_$key__charSet] = value;dynamic get classID => props[_$key__classID];  set classID(dynamic value) => props[_$key__classID] = value;dynamic get colSpan => props[_$key__colSpan];  set colSpan(dynamic value) => props[_$key__colSpan] = value;dynamic get content => props[_$key__content];  set content(dynamic value) => props[_$key__content] = value;dynamic get contentEditable => props[_$key__contentEditable];  set contentEditable(dynamic value) => props[_$key__contentEditable] = value;dynamic get contextMenu => props[_$key__contextMenu];  set contextMenu(dynamic value) => props[_$key__contextMenu] = value;dynamic get coords => props[_$key__coords];  set coords(dynamic value) => props[_$key__coords] = value;dynamic get crossOrigin => props[_$key__crossOrigin];  set crossOrigin(dynamic value) => props[_$key__crossOrigin] = value;dynamic get data => props[_$key__data];  set data(dynamic value) => props[_$key__data] = value;dynamic get dateTime => props[_$key__dateTime];  set dateTime(dynamic value) => props[_$key__dateTime] = value;
dynamic get dir => props[_$key__dir];  set dir(dynamic value) => props[_$key__dir] = value;dynamic get download => props[_$key__download];  set download(dynamic value) => props[_$key__download] = value;dynamic get draggable => props[_$key__draggable];  set draggable(dynamic value) => props[_$key__draggable] = value;dynamic get encType => props[_$key__encType];  set encType(dynamic value) => props[_$key__encType] = value;dynamic get form => props[_$key__form];  set form(dynamic value) => props[_$key__form] = value;dynamic get frameBorder => props[_$key__frameBorder];  set frameBorder(dynamic value) => props[_$key__frameBorder] = value;dynamic get height => props[_$key__height];  set height(dynamic value) => props[_$key__height] = value;dynamic get href => props[_$key__href];  set href(dynamic value) => props[_$key__href] = value;dynamic get hrefLang => props[_$key__hrefLang];  set hrefLang(dynamic value) => props[_$key__hrefLang] = value;dynamic get htmlFor => props[_$key__htmlFor];  set htmlFor(dynamic value) => props[_$key__htmlFor] = value;dynamic get httpEquiv => props[_$key__httpEquiv];  set httpEquiv(dynamic value) => props[_$key__httpEquiv] = value;dynamic get icon => props[_$key__icon];  set icon(dynamic value) => props[_$key__icon] = value;dynamic get label => props[_$key__label];  set label(dynamic value) => props[_$key__label] = value;
dynamic get lang => props[_$key__lang];  set lang(dynamic value) => props[_$key__lang] = value;dynamic get list => props[_$key__list];  set list(dynamic value) => props[_$key__list] = value;dynamic get manifest => props[_$key__manifest];  set manifest(dynamic value) => props[_$key__manifest] = value;dynamic get max => props[_$key__max];  set max(dynamic value) => props[_$key__max] = value;dynamic get maxLength => props[_$key__maxLength];  set maxLength(dynamic value) => props[_$key__maxLength] = value;dynamic get media => props[_$key__media];  set media(dynamic value) => props[_$key__media] = value;dynamic get mediaGroup => props[_$key__mediaGroup];  set mediaGroup(dynamic value) => props[_$key__mediaGroup] = value;dynamic get method => props[_$key__method];  set method(dynamic value) => props[_$key__method] = value;dynamic get min => props[_$key__min];  set min(dynamic value) => props[_$key__min] = value;dynamic get name => props[_$key__name];  set name(dynamic value) => props[_$key__name] = value;dynamic get open => props[_$key__open];  set open(dynamic value) => props[_$key__open] = value;dynamic get pattern => props[_$key__pattern];  set pattern(dynamic value) => props[_$key__pattern] = value;dynamic get placeholder => props[_$key__placeholder];  set placeholder(dynamic value) => props[_$key__placeholder] = value;
dynamic get poster => props[_$key__poster];  set poster(dynamic value) => props[_$key__poster] = value;dynamic get preload => props[_$key__preload];  set preload(dynamic value) => props[_$key__preload] = value;dynamic get radioGroup => props[_$key__radioGroup];  set radioGroup(dynamic value) => props[_$key__radioGroup] = value;dynamic get rel => props[_$key__rel];  set rel(dynamic value) => props[_$key__rel] = value;dynamic get role => props[_$key__role];  set role(dynamic value) => props[_$key__role] = value;dynamic get rowSpan => props[_$key__rowSpan];  set rowSpan(dynamic value) => props[_$key__rowSpan] = value;dynamic get sandbox => props[_$key__sandbox];  set sandbox(dynamic value) => props[_$key__sandbox] = value;dynamic get scope => props[_$key__scope];  set scope(dynamic value) => props[_$key__scope] = value;dynamic get scrolling => props[_$key__scrolling];  set scrolling(dynamic value) => props[_$key__scrolling] = value;dynamic get shape => props[_$key__shape];  set shape(dynamic value) => props[_$key__shape] = value;dynamic get sizes => props[_$key__sizes];  set sizes(dynamic value) => props[_$key__sizes] = value;dynamic get spellCheck => props[_$key__spellCheck];  set spellCheck(dynamic value) => props[_$key__spellCheck] = value;dynamic get src => props[_$key__src];  set src(dynamic value) => props[_$key__src] = value;dynamic get srcDoc => props[_$key__srcDoc];  set srcDoc(dynamic value) => props[_$key__srcDoc] = value;
dynamic get srcSet => props[_$key__srcSet];  set srcSet(dynamic value) => props[_$key__srcSet] = value;dynamic get step => props[_$key__step];  set step(dynamic value) => props[_$key__step] = value;dynamic get tabIndex => props[_$key__tabIndex];  set tabIndex(dynamic value) => props[_$key__tabIndex] = value;dynamic get target => props[_$key__target];  set target(dynamic value) => props[_$key__target] = value;dynamic get type => props[_$key__type];  set type(dynamic value) => props[_$key__type] = value;dynamic get useMap => props[_$key__useMap];  set useMap(dynamic value) => props[_$key__useMap] = value;dynamic get value => props[_$key__value];  set value(dynamic value) => props[_$key__value] = value;dynamic get width => props[_$key__width];  set width(dynamic value) => props[_$key__width] = value;dynamic get wmode => props[_$key__wmode];  set wmode(dynamic value) => props[_$key__wmode] = value;

  ClipboardEventCallback get onCopy => props[_$key__onCopy];  set onCopy(ClipboardEventCallback value) => props[_$key__onCopy] = value;ClipboardEventCallback get onCut => props[_$key__onCut];  set onCut(ClipboardEventCallback value) => props[_$key__onCut] = value;ClipboardEventCallback get onPaste => props[_$key__onPaste];  set onPaste(ClipboardEventCallback value) => props[_$key__onPaste] = value;
  KeyboardEventCallback get onKeyDown => props[_$key__onKeyDown];  set onKeyDown(KeyboardEventCallback value) => props[_$key__onKeyDown] = value;KeyboardEventCallback get onKeyPress => props[_$key__onKeyPress];  set onKeyPress(KeyboardEventCallback value) => props[_$key__onKeyPress] = value;KeyboardEventCallback get onKeyUp => props[_$key__onKeyUp];  set onKeyUp(KeyboardEventCallback value) => props[_$key__onKeyUp] = value;
  FocusEventCallback get onFocus => props[_$key__onFocus];  set onFocus(FocusEventCallback value) => props[_$key__onFocus] = value;FocusEventCallback get onBlur => props[_$key__onBlur];  set onBlur(FocusEventCallback value) => props[_$key__onBlur] = value;
  FormEventCallback get onChange => props[_$key__onChange];  set onChange(FormEventCallback value) => props[_$key__onChange] = value;FormEventCallback get onInput => props[_$key__onInput];  set onInput(FormEventCallback value) => props[_$key__onInput] = value;FormEventCallback get onSubmit => props[_$key__onSubmit];  set onSubmit(FormEventCallback value) => props[_$key__onSubmit] = value;FormEventCallback get onReset => props[_$key__onReset];  set onReset(FormEventCallback value) => props[_$key__onReset] = value;
  
MouseEventCallback get onClick => props[_$key__onClick];  set onClick(MouseEventCallback value) => props[_$key__onClick] = value;MouseEventCallback get onContextMenu => props[_$key__onContextMenu];  set onContextMenu(MouseEventCallback value) => props[_$key__onContextMenu] = value;MouseEventCallback get onDoubleClick => props[_$key__onDoubleClick];  set onDoubleClick(MouseEventCallback value) => props[_$key__onDoubleClick] = value;MouseEventCallback get onDrag => props[_$key__onDrag];  set onDrag(MouseEventCallback value) => props[_$key__onDrag] = value;MouseEventCallback get onDragEnd => props[_$key__onDragEnd];  set onDragEnd(MouseEventCallback value) => props[_$key__onDragEnd] = value;MouseEventCallback get onDragEnter => props[_$key__onDragEnter];  set onDragEnter(MouseEventCallback value) => props[_$key__onDragEnter] = value;MouseEventCallback get onDragExit => props[_$key__onDragExit];  set onDragExit(MouseEventCallback value) => props[_$key__onDragExit] = value;MouseEventCallback get onDragLeave => props[_$key__onDragLeave];  set onDragLeave(MouseEventCallback value) => props[_$key__onDragLeave] = value;MouseEventCallback get onDragOver => props[_$key__onDragOver];  set onDragOver(MouseEventCallback value) => props[_$key__onDragOver] = value;
MouseEventCallback get onDragStart => props[_$key__onDragStart];  set onDragStart(MouseEventCallback value) => props[_$key__onDragStart] = value;MouseEventCallback get onDrop => props[_$key__onDrop];  set onDrop(MouseEventCallback value) => props[_$key__onDrop] = value;MouseEventCallback get onMouseDown => props[_$key__onMouseDown];  set onMouseDown(MouseEventCallback value) => props[_$key__onMouseDown] = value;MouseEventCallback get onMouseEnter => props[_$key__onMouseEnter];  set onMouseEnter(MouseEventCallback value) => props[_$key__onMouseEnter] = value;MouseEventCallback get onMouseLeave => props[_$key__onMouseLeave];  set onMouseLeave(MouseEventCallback value) => props[_$key__onMouseLeave] = value;MouseEventCallback get onMouseMove => props[_$key__onMouseMove];  set onMouseMove(MouseEventCallback value) => props[_$key__onMouseMove] = value;MouseEventCallback get onMouseOut => props[_$key__onMouseOut];  set onMouseOut(MouseEventCallback value) => props[_$key__onMouseOut] = value;MouseEventCallback get onMouseOver => props[_$key__onMouseOver];  set onMouseOver(MouseEventCallback value) => props[_$key__onMouseOver] = value;MouseEventCallback get onMouseUp => props[_$key__onMouseUp];  set onMouseUp(MouseEventCallback value) => props[_$key__onMouseUp] = value;
  TouchEventCallback get onTouchCancel => props[_$key__onTouchCancel];  set onTouchCancel(TouchEventCallback value) => props[_$key__onTouchCancel] = value;TouchEventCallback get onTouchEnd => props[_$key__onTouchEnd];  set onTouchEnd(TouchEventCallback value) => props[_$key__onTouchEnd] = value;TouchEventCallback get onTouchMove => props[_$key__onTouchMove];  set onTouchMove(TouchEventCallback value) => props[_$key__onTouchMove] = value;TouchEventCallback get onTouchStart => props[_$key__onTouchStart];  set onTouchStart(TouchEventCallback value) => props[_$key__onTouchStart] = value;
  UIEventCallback get onScroll => props[_$key__onScroll];  set onScroll(UIEventCallback value) => props[_$key__onScroll] = value;
  WheelEventCallback get onWheel => props[_$key__onWheel];  set onWheel(WheelEventCallback value) => props[_$key__onWheel] = value;

  // props specific to React.INPUT
  bool get defaultChecked => props[_$key__defaultChecked];  set defaultChecked(bool value) => props[_$key__defaultChecked] = value;
  dynamic get defaultValue => props[_$key__defaultValue];  set defaultValue(dynamic value) => props[_$key__defaultValue] = value;

  /// Polyfills/normalizes the `autofocus` attribute via AutoFocusMixin
  /// (mixed in by React DOM <input>, <textarea>, and <select>).
  bool get autoFocus => props[_$key__autoFocus];  set autoFocus(bool value) => props[_$key__autoFocus] = value;
}

@PropsMixin(keyNamespace: '')
abstract class SvgPropsMixin {    /* GENERATED CONSTANTS */ static const ConsumedProps $consumedProps = const ConsumedProps($props, $propKeys); static const PropDescriptor _$prop__clipPath = const PropDescriptor(_$key__clipPath), _$prop__cx = const PropDescriptor(_$key__cx), _$prop__cy = const PropDescriptor(_$key__cy), _$prop__d = const PropDescriptor(_$key__d), _$prop__dx = const PropDescriptor(_$key__dx), _$prop__dy = const PropDescriptor(_$key__dy), _$prop__fill = const PropDescriptor(_$key__fill), _$prop__fillOpacity = const PropDescriptor(_$key__fillOpacity), _$prop__fontFamily = const PropDescriptor(_$key__fontFamily), _$prop__fontSize = const PropDescriptor(_$key__fontSize), _$prop__fx = const PropDescriptor(_$key__fx), _$prop__fy = const PropDescriptor(_$key__fy), _$prop__gradientTransform = const PropDescriptor(_$key__gradientTransform), _$prop__gradientUnits = const PropDescriptor(_$key__gradientUnits), _$prop__markerEnd = const PropDescriptor(_$key__markerEnd), _$prop__markerMid = const PropDescriptor(_$key__markerMid), _$prop__markerStart = const PropDescriptor(_$key__markerStart), _$prop__offset = const PropDescriptor(_$key__offset), _$prop__opacity = const PropDescriptor(_$key__opacity), _$prop__patternContentUnits = const PropDescriptor(_$key__patternContentUnits), _$prop__patternUnits = const PropDescriptor(_$key__patternUnits), _$prop__points = const PropDescriptor(_$key__points), _$prop__preserveAspectRatio = const PropDescriptor(_$key__preserveAspectRatio), _$prop__r = const PropDescriptor(_$key__r), _$prop__rx = const PropDescriptor(_$key__rx), _$prop__ry = const PropDescriptor(_$key__ry), _$prop__spreadMethod = const PropDescriptor(_$key__spreadMethod), _$prop__stopColor = const PropDescriptor(_$key__stopColor), _$prop__stopOpacity = const PropDescriptor(_$key__stopOpacity), _$prop__stroke = const PropDescriptor(_$key__stroke), _$prop__strokeDasharray = const PropDescriptor(_$key__strokeDasharray), _$prop__strokeLinecap = const PropDescriptor(_$key__strokeLinecap), _$prop__strokeOpacity = const PropDescriptor(_$key__strokeOpacity), _$prop__strokeWidth = const PropDescriptor(_$key__strokeWidth), _$prop__textAnchor = const PropDescriptor(_$key__textAnchor), _$prop__transform = const PropDescriptor(_$key__transform), _$prop__version = const PropDescriptor(_$key__version), _$prop__viewBox = const PropDescriptor(_$key__viewBox), _$prop__x1 = const PropDescriptor(_$key__x1), _$prop__x2 = const PropDescriptor(_$key__x2), _$prop__x = const PropDescriptor(_$key__x), _$prop__xlinkActuate = const PropDescriptor(_$key__xlinkActuate), _$prop__xlinkArcrole = const PropDescriptor(_$key__xlinkArcrole), _$prop__xlinkHref = const PropDescriptor(_$key__xlinkHref), _$prop__xlinkRole = const PropDescriptor(_$key__xlinkRole), _$prop__xlinkShow = const PropDescriptor(_$key__xlinkShow), _$prop__xlinkTitle = const PropDescriptor(_$key__xlinkTitle), _$prop__xlinkType = const PropDescriptor(_$key__xlinkType), _$prop__xmlBase = const PropDescriptor(_$key__xmlBase), _$prop__xmlLang = const PropDescriptor(_$key__xmlLang), _$prop__xmlSpace = const PropDescriptor(_$key__xmlSpace), _$prop__y1 = const PropDescriptor(_$key__y1), _$prop__y2 = const PropDescriptor(_$key__y2), _$prop__y = const PropDescriptor(_$key__y); static const List<PropDescriptor> $props = const [_$prop__clipPath, _$prop__cx, _$prop__cy, _$prop__d, _$prop__dx, _$prop__dy, _$prop__fill, _$prop__fillOpacity, _$prop__fontFamily, _$prop__fontSize, _$prop__fx, _$prop__fy, _$prop__gradientTransform, _$prop__gradientUnits, _$prop__markerEnd, _$prop__markerMid, _$prop__markerStart, _$prop__offset, _$prop__opacity, _$prop__patternContentUnits, _$prop__patternUnits, _$prop__points, _$prop__preserveAspectRatio, _$prop__r, _$prop__rx, _$prop__ry, _$prop__spreadMethod, _$prop__stopColor, _$prop__stopOpacity, _$prop__stroke, _$prop__strokeDasharray, _$prop__strokeLinecap, _$prop__strokeOpacity, _$prop__strokeWidth, _$prop__textAnchor, _$prop__transform, _$prop__version, _$prop__viewBox, _$prop__x1, _$prop__x2, _$prop__x, _$prop__xlinkActuate, _$prop__xlinkArcrole, _$prop__xlinkHref, _$prop__xlinkRole, _$prop__xlinkShow, _$prop__xlinkTitle, _$prop__xlinkType, _$prop__xmlBase, _$prop__xmlLang, _$prop__xmlSpace, _$prop__y1, _$prop__y2, _$prop__y]; static const String _$key__clipPath = 'clipPath', _$key__cx = 'cx', _$key__cy = 'cy', _$key__d = 'd', _$key__dx = 'dx', _$key__dy = 'dy', _$key__fill = 'fill', _$key__fillOpacity = 'fillOpacity', _$key__fontFamily = 'fontFamily', _$key__fontSize = 'fontSize', _$key__fx = 'fx', _$key__fy = 'fy', _$key__gradientTransform = 'gradientTransform', _$key__gradientUnits = 'gradientUnits', _$key__markerEnd = 'markerEnd', _$key__markerMid = 'markerMid', _$key__markerStart = 'markerStart', _$key__offset = 'offset', _$key__opacity = 'opacity', _$key__patternContentUnits = 'patternContentUnits', _$key__patternUnits = 'patternUnits', _$key__points = 'points', _$key__preserveAspectRatio = 'preserveAspectRatio', _$key__r = 'r', _$key__rx = 'rx', _$key__ry = 'ry', _$key__spreadMethod = 'spreadMethod', _$key__stopColor = 'stopColor', _$key__stopOpacity = 'stopOpacity', _$key__stroke = 'stroke', _$key__strokeDasharray = 'strokeDasharray', _$key__strokeLinecap = 'strokeLinecap', _$key__strokeOpacity = 'strokeOpacity', _$key__strokeWidth = 'strokeWidth', _$key__textAnchor = 'textAnchor', _$key__transform = 'transform', _$key__version = 'version', _$key__viewBox = 'viewBox', _$key__x1 = 'x1', _$key__x2 = 'x2', _$key__x = 'x', _$key__xlinkActuate = 'xlinkActuate', _$key__xlinkArcrole = 'xlinkArcrole', _$key__xlinkHref = 'xlinkHref', _$key__xlinkRole = 'xlinkRole', _$key__xlinkShow = 'xlinkShow', _$key__xlinkTitle = 'xlinkTitle', _$key__xlinkType = 'xlinkType', _$key__xmlBase = 'xmlBase', _$key__xmlLang = 'xmlLang', _$key__xmlSpace = 'xmlSpace', _$key__y1 = 'y1', _$key__y2 = 'y2', _$key__y = 'y'; static const List<String> $propKeys = const [_$key__clipPath, _$key__cx, _$key__cy, _$key__d, _$key__dx, _$key__dy, _$key__fill, _$key__fillOpacity, _$key__fontFamily, _$key__fontSize, _$key__fx, _$key__fy, _$key__gradientTransform, _$key__gradientUnits, _$key__markerEnd, _$key__markerMid, _$key__markerStart, _$key__offset, _$key__opacity, _$key__patternContentUnits, _$key__patternUnits, _$key__points, _$key__preserveAspectRatio, _$key__r, _$key__rx, _$key__ry, _$key__spreadMethod, _$key__stopColor, _$key__stopOpacity, _$key__stroke, _$key__strokeDasharray, _$key__strokeLinecap, _$key__strokeOpacity, _$key__strokeWidth, _$key__textAnchor, _$key__transform, _$key__version, _$key__viewBox, _$key__x1, _$key__x2, _$key__x, _$key__xlinkActuate, _$key__xlinkArcrole, _$key__xlinkHref, _$key__xlinkRole, _$key__xlinkShow, _$key__xlinkTitle, _$key__xlinkType, _$key__xmlBase, _$key__xmlLang, _$key__xmlSpace, _$key__y1, _$key__y2, _$key__y]; 
  Map get props;

  dynamic get clipPath => props[_$key__clipPath];  set clipPath(dynamic value) => props[_$key__clipPath] = value;dynamic get cx => props[_$key__cx];  set cx(dynamic value) => props[_$key__cx] = value;dynamic get cy => props[_$key__cy];  set cy(dynamic value) => props[_$key__cy] = value;dynamic get d => props[_$key__d];  set d(dynamic value) => props[_$key__d] = value;dynamic get dx => props[_$key__dx];  set dx(dynamic value) => props[_$key__dx] = value;dynamic get dy => props[_$key__dy];  set dy(dynamic value) => props[_$key__dy] = value;dynamic get fill => props[_$key__fill];  set fill(dynamic value) => props[_$key__fill] = value;dynamic get fillOpacity => props[_$key__fillOpacity];  set fillOpacity(dynamic value) => props[_$key__fillOpacity] = value;dynamic get fontFamily => props[_$key__fontFamily];  set fontFamily(dynamic value) => props[_$key__fontFamily] = value;dynamic get fontSize => props[_$key__fontSize];  set fontSize(dynamic value) => props[_$key__fontSize] = value;dynamic get fx => props[_$key__fx];  set fx(dynamic value) => props[_$key__fx] = value;dynamic get fy => props[_$key__fy];  set fy(dynamic value) => props[_$key__fy] = value;dynamic get gradientTransform => props[_$key__gradientTransform];  set gradientTransform(dynamic value) => props[_$key__gradientTransform] = value;
dynamic get gradientUnits => props[_$key__gradientUnits];  set gradientUnits(dynamic value) => props[_$key__gradientUnits] = value;dynamic get markerEnd => props[_$key__markerEnd];  set markerEnd(dynamic value) => props[_$key__markerEnd] = value;dynamic get markerMid => props[_$key__markerMid];  set markerMid(dynamic value) => props[_$key__markerMid] = value;dynamic get markerStart => props[_$key__markerStart];  set markerStart(dynamic value) => props[_$key__markerStart] = value;dynamic get offset => props[_$key__offset];  set offset(dynamic value) => props[_$key__offset] = value;dynamic get opacity => props[_$key__opacity];  set opacity(dynamic value) => props[_$key__opacity] = value;dynamic get patternContentUnits => props[_$key__patternContentUnits];  set patternContentUnits(dynamic value) => props[_$key__patternContentUnits] = value;dynamic get patternUnits => props[_$key__patternUnits];  set patternUnits(dynamic value) => props[_$key__patternUnits] = value;dynamic get points => props[_$key__points];  set points(dynamic value) => props[_$key__points] = value;
dynamic get preserveAspectRatio => props[_$key__preserveAspectRatio];  set preserveAspectRatio(dynamic value) => props[_$key__preserveAspectRatio] = value;dynamic get r => props[_$key__r];  set r(dynamic value) => props[_$key__r] = value;dynamic get rx => props[_$key__rx];  set rx(dynamic value) => props[_$key__rx] = value;dynamic get ry => props[_$key__ry];  set ry(dynamic value) => props[_$key__ry] = value;dynamic get spreadMethod => props[_$key__spreadMethod];  set spreadMethod(dynamic value) => props[_$key__spreadMethod] = value;dynamic get stopColor => props[_$key__stopColor];  set stopColor(dynamic value) => props[_$key__stopColor] = value;dynamic get stopOpacity => props[_$key__stopOpacity];  set stopOpacity(dynamic value) => props[_$key__stopOpacity] = value;dynamic get stroke => props[_$key__stroke];  set stroke(dynamic value) => props[_$key__stroke] = value;dynamic get strokeDasharray => props[_$key__strokeDasharray];  set strokeDasharray(dynamic value) => props[_$key__strokeDasharray] = value;dynamic get strokeLinecap => props[_$key__strokeLinecap];  set strokeLinecap(dynamic value) => props[_$key__strokeLinecap] = value;
dynamic get strokeOpacity => props[_$key__strokeOpacity];  set strokeOpacity(dynamic value) => props[_$key__strokeOpacity] = value;dynamic get strokeWidth => props[_$key__strokeWidth];  set strokeWidth(dynamic value) => props[_$key__strokeWidth] = value;dynamic get textAnchor => props[_$key__textAnchor];  set textAnchor(dynamic value) => props[_$key__textAnchor] = value;dynamic get transform => props[_$key__transform];  set transform(dynamic value) => props[_$key__transform] = value;dynamic get version => props[_$key__version];  set version(dynamic value) => props[_$key__version] = value;dynamic get viewBox => props[_$key__viewBox];  set viewBox(dynamic value) => props[_$key__viewBox] = value;dynamic get x1 => props[_$key__x1];  set x1(dynamic value) => props[_$key__x1] = value;dynamic get x2 => props[_$key__x2];  set x2(dynamic value) => props[_$key__x2] = value;dynamic get x => props[_$key__x];  set x(dynamic value) => props[_$key__x] = value;dynamic get xlinkActuate => props[_$key__xlinkActuate];  set xlinkActuate(dynamic value) => props[_$key__xlinkActuate] = value;dynamic get xlinkArcrole => props[_$key__xlinkArcrole];  set xlinkArcrole(dynamic value) => props[_$key__xlinkArcrole] = value;
dynamic get xlinkHref => props[_$key__xlinkHref];  set xlinkHref(dynamic value) => props[_$key__xlinkHref] = value;dynamic get xlinkRole => props[_$key__xlinkRole];  set xlinkRole(dynamic value) => props[_$key__xlinkRole] = value;dynamic get xlinkShow => props[_$key__xlinkShow];  set xlinkShow(dynamic value) => props[_$key__xlinkShow] = value;dynamic get xlinkTitle => props[_$key__xlinkTitle];  set xlinkTitle(dynamic value) => props[_$key__xlinkTitle] = value;dynamic get xlinkType => props[_$key__xlinkType];  set xlinkType(dynamic value) => props[_$key__xlinkType] = value;dynamic get xmlBase => props[_$key__xmlBase];  set xmlBase(dynamic value) => props[_$key__xmlBase] = value;dynamic get xmlLang => props[_$key__xmlLang];  set xmlLang(dynamic value) => props[_$key__xmlLang] = value;dynamic get xmlSpace => props[_$key__xmlSpace];  set xmlSpace(dynamic value) => props[_$key__xmlSpace] = value;dynamic get y1 => props[_$key__y1];  set y1(dynamic value) => props[_$key__y1] = value;dynamic get y2 => props[_$key__y2];  set y2(dynamic value) => props[_$key__y2] = value;dynamic get y => props[_$key__y];  set y(dynamic value) => props[_$key__y] = value;
}

/// Typed getters/setters for reserved DOM-related props that can be used by all UIP components.
/// To be used as a mixin for React components and builders.
@PropsMixin(keyNamespace: '')
abstract class UbiquitousDomPropsMixin {    /* GENERATED CONSTANTS */ static const ConsumedProps $consumedProps = const ConsumedProps($props, $propKeys); static const PropDescriptor _$prop__tabIndex = const PropDescriptor(_$key__tabIndex), _$prop__id = const PropDescriptor(_$key__id), _$prop__title = const PropDescriptor(_$key__title), _$prop__style = const PropDescriptor(_$key__style), _$prop__onCopy = const PropDescriptor(_$key__onCopy), _$prop__onCut = const PropDescriptor(_$key__onCut), _$prop__onPaste = const PropDescriptor(_$key__onPaste), _$prop__onKeyDown = const PropDescriptor(_$key__onKeyDown), _$prop__onKeyPress = const PropDescriptor(_$key__onKeyPress), _$prop__onKeyUp = const PropDescriptor(_$key__onKeyUp), _$prop__onFocus = const PropDescriptor(_$key__onFocus), _$prop__onBlur = const PropDescriptor(_$key__onBlur), _$prop__onChange = const PropDescriptor(_$key__onChange), _$prop__onInput = const PropDescriptor(_$key__onInput), _$prop__onSubmit = const PropDescriptor(_$key__onSubmit), _$prop__onReset = const PropDescriptor(_$key__onReset), _$prop__onClick = const PropDescriptor(_$key__onClick), _$prop__onContextMenu = const PropDescriptor(_$key__onContextMenu), _$prop__onDoubleClick = const PropDescriptor(_$key__onDoubleClick), _$prop__onDrag = const PropDescriptor(_$key__onDrag), _$prop__onDragEnd = const PropDescriptor(_$key__onDragEnd), _$prop__onDragEnter = const PropDescriptor(_$key__onDragEnter), _$prop__onDragExit = const PropDescriptor(_$key__onDragExit), _$prop__onDragLeave = const PropDescriptor(_$key__onDragLeave), _$prop__onDragOver = const PropDescriptor(_$key__onDragOver), _$prop__onDragStart = const PropDescriptor(_$key__onDragStart), _$prop__onDrop = const PropDescriptor(_$key__onDrop), _$prop__onMouseDown = const PropDescriptor(_$key__onMouseDown), _$prop__onMouseEnter = const PropDescriptor(_$key__onMouseEnter), _$prop__onMouseLeave = const PropDescriptor(_$key__onMouseLeave), _$prop__onMouseMove = const PropDescriptor(_$key__onMouseMove), _$prop__onMouseOut = const PropDescriptor(_$key__onMouseOut), _$prop__onMouseOver = const PropDescriptor(_$key__onMouseOver), _$prop__onMouseUp = const PropDescriptor(_$key__onMouseUp), _$prop__onTouchCancel = const PropDescriptor(_$key__onTouchCancel), _$prop__onTouchEnd = const PropDescriptor(_$key__onTouchEnd), _$prop__onTouchMove = const PropDescriptor(_$key__onTouchMove), _$prop__onTouchStart = const PropDescriptor(_$key__onTouchStart), _$prop__onScroll = const PropDescriptor(_$key__onScroll), _$prop__onWheel = const PropDescriptor(_$key__onWheel); static const List<PropDescriptor> $props = const [_$prop__tabIndex, _$prop__id, _$prop__title, _$prop__style, _$prop__onCopy, _$prop__onCut, _$prop__onPaste, _$prop__onKeyDown, _$prop__onKeyPress, _$prop__onKeyUp, _$prop__onFocus, _$prop__onBlur, _$prop__onChange, _$prop__onInput, _$prop__onSubmit, _$prop__onReset, _$prop__onClick, _$prop__onContextMenu, _$prop__onDoubleClick, _$prop__onDrag, _$prop__onDragEnd, _$prop__onDragEnter, _$prop__onDragExit, _$prop__onDragLeave, _$prop__onDragOver, _$prop__onDragStart, _$prop__onDrop, _$prop__onMouseDown, _$prop__onMouseEnter, _$prop__onMouseLeave, _$prop__onMouseMove, _$prop__onMouseOut, _$prop__onMouseOver, _$prop__onMouseUp, _$prop__onTouchCancel, _$prop__onTouchEnd, _$prop__onTouchMove, _$prop__onTouchStart, _$prop__onScroll, _$prop__onWheel]; static const String _$key__tabIndex = 'tabIndex', _$key__id = 'id', _$key__title = 'title', _$key__style = 'style', _$key__onCopy = 'onCopy', _$key__onCut = 'onCut', _$key__onPaste = 'onPaste', _$key__onKeyDown = 'onKeyDown', _$key__onKeyPress = 'onKeyPress', _$key__onKeyUp = 'onKeyUp', _$key__onFocus = 'onFocus', _$key__onBlur = 'onBlur', _$key__onChange = 'onChange', _$key__onInput = 'onInput', _$key__onSubmit = 'onSubmit', _$key__onReset = 'onReset', _$key__onClick = 'onClick', _$key__onContextMenu = 'onContextMenu', _$key__onDoubleClick = 'onDoubleClick', _$key__onDrag = 'onDrag', _$key__onDragEnd = 'onDragEnd', _$key__onDragEnter = 'onDragEnter', _$key__onDragExit = 'onDragExit', _$key__onDragLeave = 'onDragLeave', _$key__onDragOver = 'onDragOver', _$key__onDragStart = 'onDragStart', _$key__onDrop = 'onDrop', _$key__onMouseDown = 'onMouseDown', _$key__onMouseEnter = 'onMouseEnter', _$key__onMouseLeave = 'onMouseLeave', _$key__onMouseMove = 'onMouseMove', _$key__onMouseOut = 'onMouseOut', _$key__onMouseOver = 'onMouseOver', _$key__onMouseUp = 'onMouseUp', _$key__onTouchCancel = 'onTouchCancel', _$key__onTouchEnd = 'onTouchEnd', _$key__onTouchMove = 'onTouchMove', _$key__onTouchStart = 'onTouchStart', _$key__onScroll = 'onScroll', _$key__onWheel = 'onWheel'; static const List<String> $propKeys = const [_$key__tabIndex, _$key__id, _$key__title, _$key__style, _$key__onCopy, _$key__onCut, _$key__onPaste, _$key__onKeyDown, _$key__onKeyPress, _$key__onKeyUp, _$key__onFocus, _$key__onBlur, _$key__onChange, _$key__onInput, _$key__onSubmit, _$key__onReset, _$key__onClick, _$key__onContextMenu, _$key__onDoubleClick, _$key__onDrag, _$key__onDragEnd, _$key__onDragEnter, _$key__onDragExit, _$key__onDragLeave, _$key__onDragOver, _$key__onDragStart, _$key__onDrop, _$key__onMouseDown, _$key__onMouseEnter, _$key__onMouseLeave, _$key__onMouseMove, _$key__onMouseOut, _$key__onMouseOver, _$key__onMouseUp, _$key__onTouchCancel, _$key__onTouchEnd, _$key__onTouchMove, _$key__onTouchStart, _$key__onScroll, _$key__onWheel]; 
  Map get props;

  /// Whether the element if focusable.
  /// Must be a valid integer or String of valid integer.
  dynamic get tabIndex => props[_$key__tabIndex];  set tabIndex(dynamic value) => props[_$key__tabIndex] = value;

  /// Unique identifier.
  /// Must be unique amongst all the ids, and contain at least one character.
  String get id => props[_$key__id];  set id(String value) => props[_$key__id] = value;

  /// Represents advisory information about the element.
  String get title => props[_$key__title];  set title(String value) => props[_$key__title] = value;

  /// An inline CSS style for the element.
  ///
  ///     ..style = {
  ///       'width': '${state.progress * 100}%',
  ///       'display': state.isHidden ? 'none' : '',
  ///     }
  ///
  /// See: <https://facebook.github.io/react/tips/inline-styles.html>
  Map<String, dynamic> get style => props[_$key__style];  set style(Map<String, dynamic> value) => props[_$key__style] = value;

  /// Callback for when the user copies the content of an element
  ClipboardEventCallback get onCopy => props[_$key__onCopy];  set onCopy(ClipboardEventCallback value) => props[_$key__onCopy] = value;

  /// Callback for when the user cuts the content of an element
  ClipboardEventCallback get onCut => props[_$key__onCut];  set onCut(ClipboardEventCallback value) => props[_$key__onCut] = value;

  /// Callback for when the user pastes some content in an element
  ClipboardEventCallback get onPaste => props[_$key__onPaste];  set onPaste(ClipboardEventCallback value) => props[_$key__onPaste] = value;

  /// Callback for when the user is pressing a key
  KeyboardEventCallback get onKeyDown => props[_$key__onKeyDown];  set onKeyDown(KeyboardEventCallback value) => props[_$key__onKeyDown] = value;

  /// Callback for when the user presses a key
  KeyboardEventCallback get onKeyPress => props[_$key__onKeyPress];  set onKeyPress(KeyboardEventCallback value) => props[_$key__onKeyPress] = value;

  /// Callback for when the user releases a key
  KeyboardEventCallback get onKeyUp => props[_$key__onKeyUp];  set onKeyUp(KeyboardEventCallback value) => props[_$key__onKeyUp] = value;

  /// Callback for when an element gets focus
  FocusEventCallback get onFocus => props[_$key__onFocus];  set onFocus(FocusEventCallback value) => props[_$key__onFocus] = value;

  /// Callback for when an element loses focus
  FocusEventCallback get onBlur => props[_$key__onBlur];  set onBlur(FocusEventCallback value) => props[_$key__onBlur] = value;

  /// Callback for  when the content of a form element, the selection, or the checked state have changed (for <input>,
  /// <keygen>, <select>, and <textarea>)
  FormEventCallback get onChange => props[_$key__onChange];  set onChange(FormEventCallback value) => props[_$key__onChange] = value;

  /// Callback for when an element gets user input
  FormEventCallback get onInput => props[_$key__onInput];  set onInput(FormEventCallback value) => props[_$key__onInput] = value;

  /// Callback for when a form is submitted
  FormEventCallback get onSubmit => props[_$key__onSubmit];  set onSubmit(FormEventCallback value) => props[_$key__onSubmit] = value;

  /// Callback for when a form is reset
  FormEventCallback get onReset => props[_$key__onReset];  set onReset(FormEventCallback value) => props[_$key__onReset] = value;

  /// Callback for when the user clicks on an element
  MouseEventCallback get onClick => props[_$key__onClick];  set onClick(MouseEventCallback value) => props[_$key__onClick] = value;

  /// Callback for when the user right-clicks on an element to open a context menu
  MouseEventCallback get onContextMenu => props[_$key__onContextMenu];  set onContextMenu(MouseEventCallback value) => props[_$key__onContextMenu] = value;

  /// Callback for when the user double-clicks on an element
  MouseEventCallback get onDoubleClick => props[_$key__onDoubleClick];  set onDoubleClick(MouseEventCallback value) => props[_$key__onDoubleClick] = value;

  /// Callback for when an element is being dragged
  MouseEventCallback get onDrag => props[_$key__onDrag];  set onDrag(MouseEventCallback value) => props[_$key__onDrag] = value;

  /// Callback for when the user has finished dragging an element
  MouseEventCallback get onDragEnd => props[_$key__onDragEnd];  set onDragEnd(MouseEventCallback value) => props[_$key__onDragEnd] = value;

  /// Callback for when the dragged element enters the drop target
  MouseEventCallback get onDragEnter => props[_$key__onDragEnter];  set onDragEnter(MouseEventCallback value) => props[_$key__onDragEnter] = value;

  /// Callback for when the dragged element exits the drop target
  MouseEventCallback get onDragExit => props[_$key__onDragExit];  set onDragExit(MouseEventCallback value) => props[_$key__onDragExit] = value;

  /// Callback for when the dragged element leaves the drop target
  MouseEventCallback get onDragLeave => props[_$key__onDragLeave];  set onDragLeave(MouseEventCallback value) => props[_$key__onDragLeave] = value;

  /// Callback for when the dragged element is over the drop target
  MouseEventCallback get onDragOver => props[_$key__onDragOver];  set onDragOver(MouseEventCallback value) => props[_$key__onDragOver] = value;

  /// Callback for when the user starts to drag an element
  MouseEventCallback get onDragStart => props[_$key__onDragStart];  set onDragStart(MouseEventCallback value) => props[_$key__onDragStart] = value;

  /// Callback for when the dragged element is dropped on the drop target
  MouseEventCallback get onDrop => props[_$key__onDrop];  set onDrop(MouseEventCallback value) => props[_$key__onDrop] = value;

  /// Callback for when the user presses a mouse button over an element
  MouseEventCallback get onMouseDown => props[_$key__onMouseDown];  set onMouseDown(MouseEventCallback value) => props[_$key__onMouseDown] = value;

  /// Callback for when the pointer is moved onto an element
  MouseEventCallback get onMouseEnter => props[_$key__onMouseEnter];  set onMouseEnter(MouseEventCallback value) => props[_$key__onMouseEnter] = value;

  /// Callback for when the pointer is moved out of an element
  MouseEventCallback get onMouseLeave => props[_$key__onMouseLeave];  set onMouseLeave(MouseEventCallback value) => props[_$key__onMouseLeave] = value;

  /// Callback for when the pointer is moving while it is over an element
  MouseEventCallback get onMouseMove => props[_$key__onMouseMove];  set onMouseMove(MouseEventCallback value) => props[_$key__onMouseMove] = value;

  /// Callback for when a user moves the mouse pointer out of an element, or out of one of its children
  MouseEventCallback get onMouseOut => props[_$key__onMouseOut];  set onMouseOut(MouseEventCallback value) => props[_$key__onMouseOut] = value;

  /// Callback for when the pointer is moved onto an element, or onto one of its children
  MouseEventCallback get onMouseOver => props[_$key__onMouseOver];  set onMouseOver(MouseEventCallback value) => props[_$key__onMouseOver] = value;

  /// Callback for when a user releases a mouse button over an element
  MouseEventCallback get onMouseUp => props[_$key__onMouseUp];  set onMouseUp(MouseEventCallback value) => props[_$key__onMouseUp] = value;

  /// Callback for when the touch is interrupted
  TouchEventCallback get onTouchCancel => props[_$key__onTouchCancel];  set onTouchCancel(TouchEventCallback value) => props[_$key__onTouchCancel] = value;

  /// Callback for when a finger is removed from a touch screen
  TouchEventCallback get onTouchEnd => props[_$key__onTouchEnd];  set onTouchEnd(TouchEventCallback value) => props[_$key__onTouchEnd] = value;

  /// Callback for when a finger is dragged across the screen
  TouchEventCallback get onTouchMove => props[_$key__onTouchMove];  set onTouchMove(TouchEventCallback value) => props[_$key__onTouchMove] = value;

  /// Callback for when a finger is placed on a touch screen
  TouchEventCallback get onTouchStart => props[_$key__onTouchStart];  set onTouchStart(TouchEventCallback value) => props[_$key__onTouchStart] = value;

  /// Callback for when an element's scrollbar is being scrolled
  UIEventCallback get onScroll => props[_$key__onScroll];  set onScroll(UIEventCallback value) => props[_$key__onScroll] = value;

  /// Callback for when the mouse wheel rolls up or down over an element
  WheelEventCallback get onWheel => props[_$key__onWheel];  set onWheel(WheelEventCallback value) => props[_$key__onWheel] = value;
}
